<?php
/**
 * Create and render "welcome" page
 *
 * @package gap_block
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( defined( 'WDP_SUMMARY_PAGE' ) ) {
	return;
}

define( 'WDP_SUMMARY_PAGE', true ); // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedConstantFound

add_action( 'admin_menu', array( 'WDPGB_BlocksSummaryPage', 'register_blocks_summary_page' ) );
add_action( 'admin_enqueue_scripts', array( 'WDPGB_BlocksSummaryPage', 'enqueue_scripts' ) );

/**
 * Blocks summary page class
 */
abstract class WDPGB_BlocksSummaryPage {

	/**
	 * Register blocks summary page
	 */
	public static function register_blocks_summary_page() {

		add_options_page(
			esc_html( __( 'Blocks by We Do Plugins', 'gap-block' ) ),
			esc_html( __( 'Blocks by We Do Plugins', 'gap-block' ) ),
			'manage_options',
			'wdp-blocks-summary',
			array( get_class(), 'render_blocks_summary_page' )
		);
	}

	/**
	 * Enqueue admin scripts
	 */
	public static function enqueue_scripts() {

		if ( 'settings_page_wdp-blocks-summary' === get_current_screen()->id ) {

			wp_enqueue_style( 'wdp-blocks-summary', plugins_url( 'build/blocks-summary.css', WDPGB_MAIN_FILE ), array(), WDPGB_VERSION );
			wp_enqueue_script( 'wdp-blocks-summary-plugins-table', plugins_url( 'build/plugins-table.min.js', WDPGB_MAIN_FILE ), array( 'wp-i18n' ), WDPGB_VERSION, true );

			wp_localize_script(
				'wdp-blocks-summary-plugins-table',
				'wdpBlocksSummaryPluginsTable',
				array(
					'usedPlugins' => self::get_used_plugins_data(),
				)
			);
		}
	}

	/**
	 * Get data of used plugins by We Do Plugins
	 */
	private static function get_used_plugins_data() {

		if ( ! function_exists( 'get_plugins' ) ) {
			require_once ABSPATH . 'wp-admin/includes/plugin.php';
		}

		$plugins = get_plugins();
		$result  = array(
			'installed' => array(),
			'active'    => array(),
		);

		foreach ( $plugins as $plugin_path => $plugin_data ) {

			if ( 'We Do Plugins' !== $plugin_data['AuthorName'] ) {
				continue;
			}

			$slug = explode( '/', $plugin_path );
			$slug = $slug[0] ?? null;

			if ( null !== $slug ) {

				if ( is_plugin_active( "$slug/$slug.php" ) ) {
					$result['active'][] = $slug;
				} else {
					$result['installed'][] = $slug;
				}
			}
		}

		return $result;
	}

	/**
	 * Render blocks summary page
	 */
	public static function render_blocks_summary_page() {

		$path = plugin_dir_url( WDPGB_MAIN_FILE ) . 'assets/img/';

		?>
		<div class="wrap wdp-blocks-summary">
			<div class="wdp-blocks-summary__heading"></div>
			<div class="wdp-blocks-summary__container">
				<div class="wdp-blocks-summary__container__content">
					<img src="https://secure.gravatar.com/avatar/ddc4f734fb15df230a163bc2643fb026?s=100&d=mm&r=g" alt="<?php echo esc_html( __( 'We Do Plugins', 'gap-block' ) ); ?>" class="wdp-blocks-summary__container__content__icon" />
					<h1><?php echo esc_html( __( 'Blocks by We Do Plugins', 'gap-block' ) ); ?></h1>
					<p>
						<?php echo esc_html( __( 'We offer plugins that helps you build and maintain your website.', 'gap-block' ) ); ?><br>
						<?php echo esc_html( __( 'If you haven\'t already, check our plugins portfolio and improve your website today.', 'gap-block' ) ); ?>
					</p>
					<div class="wdp-blocks-summary__settings">
						<h2><?php echo esc_html( __( 'Blocks settings', 'gap-block' ) ); ?></h2>
						<?php do_action( 'wdp_blocks_summary_settings' ); // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals ?>
					</div>
					<h2><?php echo esc_html( __( 'Check other our plugins', 'gap-block' ) ); ?></h2>
					<div id="wdp-blocks-summary__plugins-table__container"></div>
				</div>
			</div>
		</div>
		<?php
	}
}
